.. _tutorials-hello-world:

==================
Hello World!
==================

The code for this example is located in the :mod:`examples.helloworld.manage`
module.

.. automodule:: examples.helloworld.manage